@@ -50,12 +50,10 @@ struct stepper
     {
         // U[t][i] is the state of position i at time t.
         std::vector<space> U(2);
-        for (space& s : U)
-            s.resize(nx);
+        for (space& s : U) s.resize(nx);
 
         // Initial conditions: f(0, i) = i
-        for (std::size_t i = 0; i != nx; ++i)
-            U[0][i] = double(i);
+        for (std::size_t i = 0; i != nx; ++i) U[0][i] = double(i);
 
         // Actual time step loop
         for (std::size_t t = 0; t != nt; ++t)
@@ -82,8 +80,7 @@ int pika_main(pika::program_options::variables_map& vm)
     std::uint64_t nx = vm["nx"].as<std::uint64_t>();    // Number of grid points.
     std::uint64_t nt = vm["nt"].as<std::uint64_t>();    // Number of steps.
 
-    if (vm.count("no-header"))
-        header = false;
+    if (vm.count("no-header")) header = false;
 
     // Create the stepper object
     stepper step;
