@@ -6,8 +6,9 @@
 
 #pragma once
 
-#include <pika/chrono.hpp>
+#include <pika/timing/high_resolution_timer.hpp>
 
+#include <chrono>
 #include <cstddef>
 #include <cstdint>
 #include <memory>
@@ -18,8 +19,8 @@
 #include "jacobi.hpp"
 
 namespace jacobi_smp {
-    void jacobi(std::size_t n, std::size_t iterations, std::size_t,
-        std::string const& output_filename)
+    void jacobi(
+        std::size_t n, std::size_t iterations, std::size_t, std::string const& output_filename)
     {
         using vector = std::vector<double>;
 
