@@ -12,10 +12,7 @@
 
 #include <iostream>
 
-int get_id(int i)
-{
-    return i;
-}
+int get_id(int i) { return i; }
 
 int func1()
 {
@@ -23,7 +20,7 @@ int func1()
     return get_id(1) ? 123 : 0;
 }
 
-// this continuation function will be executed by an pika thread
+// this continuation function will be executed by a pika thread
 int cont1(pika::future<int> f)
 {
     std::cout << "cont1 thread id: " << pika::this_thread::get_id() << std::endl;
@@ -33,7 +30,7 @@ int cont1(pika::future<int> f)
 }
 
 // this continuation function will be executed by the UI (main) thread, which is
-// not an pika thread
+// not a pika thread
 int cont2(pika::future<int> f)
 {
     std::cout << "Status code (main thread): " << f.get() << std::endl;
@@ -59,7 +56,4 @@ int pika_main()
     return pika::finalize();
 }
 
-int main(int argc, char* argv[])
-{
-    return pika::init(pika_main, argc, argv);
-}
+int main(int argc, char* argv[]) { return pika::init(pika_main, argc, argv); }
