@@ -13,32 +13,20 @@
 #include <cstdint>
 
 ///////////////////////////////////////////////////////////////////////////////
-std::int32_t increment(std::int32_t i)
-{
-    return i + 1;
-}
+std::int32_t increment(std::int32_t i) { return i + 1; }
 
-std::int32_t increment_with_future(pika::shared_future<std::int32_t> fi)
-{
-    return fi.get() + 1;
-}
+std::int32_t increment_with_future(pika::shared_future<std::int32_t> fi) { return fi.get() + 1; }
 
 ///////////////////////////////////////////////////////////////////////////////
 struct mult2
 {
-    std::int32_t operator()(std::int32_t i) const
-    {
-        return i * 2;
-    }
+    std::int32_t operator()(std::int32_t i) const { return i * 2; }
 };
 
 ///////////////////////////////////////////////////////////////////////////////
 struct decrement
 {
-    std::int32_t call(std::int32_t i) const
-    {
-        return i - 1;
-    }
+    std::int32_t call(std::int32_t i) const { return i - 1; }
 };
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -251,8 +239,7 @@ int pika_main()
 
         std::atomic<int> count(0);
         auto policy2 = pika::launch::select([&count]() -> pika::launch {
-            if (count++ == 0)
-                return pika::launch::async;
+            if (count++ == 0) return pika::launch::async;
             return pika::launch::sync;
         });
 
