@@ -75,8 +75,7 @@ namespace pika::detail {
 
     std::string enquote(std::string const& arg)
     {
-        if (arg.find_first_of(" \t\"") != std::string::npos)
-            return std::string("\"") + arg + "\"";
+        if (arg.find_first_of(" \t\"") != std::string::npos) return std::string("\"") + arg + "\"";
         return arg;
     }
 
@@ -85,83 +84,12 @@ namespace pika::detail {
         using size_type = std::string::size_type;
 
         size_type first = s.find_first_not_of(" \t");
-        if (std::string::npos == first)
-            return std::string();
+        if (std::string::npos == first) return std::string();
 
         size_type last = s.find_last_not_of(" \t");
         return s.substr(first, last - first + 1);
     }
 
-    ///////////////////////////////////////////////////////////////////////
-    // Handle aliasing of command line options based on information stored
-    // in the ini-configuration
-    std::pair<std::string, std::string> handle_aliasing(
-        pika::detail::section const& ini, std::string const& option)
-    {
-        std::pair<std::string, std::string> result;
-
-        std::string opt(trim_whitespace(option));
-        if (opt.size() < 2 || opt[0] != '-')
-            return result;
-
-        pika::detail::section const* sec = ini.get_section("pika.commandline.aliases");
-        if (nullptr == sec)
-            return result;    // no alias mappings are defined
-
-        // we found shortcut option definitions, try to find mapping
-        std::string expand_to;
-        std::string::size_type start_at = 2;
-        bool long_option = false;
-        if (opt.size() > 2 && opt[1] != '-')
-        {
-            // short option with value: first two letters have to match
-            expand_to = trim_whitespace(sec->get_entry(opt.substr(0, start_at), ""));
-        }
-        else
-        {
-            // short option (no value) or long option
-            if (opt[1] == '-')
-            {
-                start_at = opt.find_last_of('=');
-                long_option = true;
-            }
-
-            if (start_at != std::string::npos)
-            {
-                expand_to = trim_whitespace(sec->get_entry(opt.substr(0, start_at), ""));
-            }
-            else
-            {
-                expand_to = trim_whitespace(sec->get_entry(opt, ""));
-            }
-        }
-
-        if (expand_to.size() < 2 || expand_to.substr(0, 2) != "--")
-            return result;    // no sensible alias is defined for this option
-        expand_to.erase(0, 2);
-
-        std::string::size_type p = expand_to.find_first_of('=');
-        if (p != std::string::npos)
-        {
-            // the option alias defines its own value
-            std::string o(trim_whitespace(expand_to.substr(0, p)));
-            std::string v(trim_whitespace(expand_to.substr(p + 1)));
-            result = std::make_pair(o, v);
-        }
-        else if (start_at != std::string::npos && start_at < opt.size())
-        {
-            // extract value from original option
-            result = std::make_pair(expand_to, opt.substr(start_at + (long_option ? 1 : 0)));
-        }
-        else
-        {
-            // no value
-            result = std::make_pair(expand_to, std::string());
-        }
-
-        return result;
-    }
-
     ///////////////////////////////////////////////////////////////////////
     // Additional command line parser which interprets '@something' as an
     // option "options-file" with the value "something". Additionally we
@@ -177,15 +105,9 @@ namespace pika::detail {
         std::pair<std::string, std::string> operator()(std::string const& s) const
         {
             // handle special syntax for configuration files @filename
-            if ('@' == s[0])
-                return std::make_pair(std::string("pika:options-file"), s.substr(1));
+            if ('@' == s[0]) return std::make_pair(std::string("pika:options-file"), s.substr(1));
 
-            // handle aliasing, if enabled
-            if (ini_.get_entry("pika.commandline.aliasing", "0") == "0" || ignore_aliases_)
-            {
-                return std::make_pair(std::string(), std::string());
-            }
-            return handle_aliasing(ini_, s);
+            return std::make_pair(std::string(), std::string());
         }
 
         pika::detail::section const& ini_;
@@ -228,8 +150,7 @@ namespace pika::detail {
         {
             // skip empty lines
             std::string::size_type pos = line.find_first_not_of(" \t");
-            if (pos == std::string::npos)
-                continue;
+            if (pos == std::string::npos) continue;
 
             // strip leading and trailing whitespace
             line = trim_whitespace(line);
@@ -280,8 +201,7 @@ namespace pika::detail {
         pika::program_options::options_description const& desc_cfgfile,
         pika::detail::section const& ini, commandline_error_mode error_mode)
     {
-        if (appname.empty())
-            return;
+        if (appname.empty()) return;
 
         std::filesystem::path dir(filesystem::initial_path());
         std::filesystem::path app(appname);
@@ -293,13 +213,11 @@ namespace pika::detail {
             std::filesystem::path filename = dir / (appname + ".cfg");
             bool result = read_config_file_options(filename.string(), desc_cfgfile, vm, ini,
                 error_mode & ~commandline_error_mode::report_missing_config_file);
-            if (result)
-                break;    // break on the first options file found
+            if (result) break;    // break on the first options file found
 
             auto dir_prev = dir;
             dir = dir.parent_path();    // chop off last directory part
-            if (dir_prev == dir)
-                break;
+            if (dir_prev == dir) break;
         }
     }
 
@@ -385,6 +303,13 @@ namespace pika::detail {
                   "values. Do not use with --pika:pu-step, --pika:pu-offset, or "
                   "--pika:affinity options. Implies --pika:numa-sensitive=1"
                   "(--pika:bind=none disables defining thread affinities).")
+                ("pika:process-mask", value<std::string>(),
+                  "a process mask in hexadecimal form to restrict cores available for "
+                  "the pika runtime. If a mask has been set externally on the executable, "
+                  "this option overrides that mask. Has no effect if "
+                  "--pika:ignore-process-mask is used. This option does not set the "
+                  "process mask for the main thread. The mask only affects threads spawned "
+                  "by the pika runtime.")
                 ("pika:ignore-process-mask", "ignore the process mask to restrict "
                  "available hardware resources, use all available processing units")
                 ("pika:print-bind",
