@@ -213,10 +213,7 @@ namespace pika {
 
             ~std_exception() noexcept {}
 
-            const char* what() const noexcept override
-            {
-                return what_.c_str();
-            }
+            const char* what() const noexcept override { return what_.c_str(); }
         };
 
         struct PIKA_EXPORT bad_alloc : std::bad_alloc
@@ -232,10 +229,7 @@ namespace pika {
 
             ~bad_alloc() noexcept {}
 
-            const char* what() const noexcept override
-            {
-                return what_.c_str();
-            }
+            const char* what() const noexcept override { return what_.c_str(); }
         };
 
         struct PIKA_EXPORT bad_exception : std::bad_exception
@@ -251,10 +245,7 @@ namespace pika {
 
             ~bad_exception() noexcept {}
 
-            const char* what() const noexcept override
-            {
-                return what_.c_str();
-            }
+            const char* what() const noexcept override { return what_.c_str(); }
         };
 
         struct PIKA_EXPORT bad_cast : std::bad_cast
@@ -270,10 +261,7 @@ namespace pika {
 
             ~bad_cast() noexcept {}
 
-            const char* what() const noexcept override
-            {
-                return what_.c_str();
-            }
+            const char* what() const noexcept override { return what_.c_str(); }
         };
 
         struct PIKA_EXPORT bad_typeid : std::bad_typeid
@@ -289,10 +277,7 @@ namespace pika {
 
             ~bad_typeid() noexcept {}
 
-            const char* what() const noexcept override
-            {
-                return what_.c_str();
-            }
+            const char* what() const noexcept override { return what_.c_str(); }
         };
 
         template <typename Exception>
@@ -350,16 +335,12 @@ namespace pika {
     inline std::string get_error_what(pika::error_code const& e)
     {
         // if this is a lightweight error_code, return canned response
-        if (e.category() == detail::get_lightweight_pika_category())
-            return e.message();
+        if (e.category() == detail::get_lightweight_pika_category()) return e.message();
 
         return get_error_what<pika::error_code>(e);
     }
 
-    inline std::string get_error_what(std::exception const& e)
-    {
-        return e.what();
-    }
+    inline std::string get_error_what(std::exception const& e) { return e.what(); }
     /// \endcond
 
     /// \brief Return the error code value of the exception thrown.
