@@ -121,7 +121,7 @@ namespace pika::drop_value_detail {
         }
 
         friend constexpr decltype(auto) tag_invoke(
-            pika::execution::experimental::get_env_t, drop_value_sender_type const& s)
+            pika::execution::experimental::get_env_t, drop_value_sender_type const& s) noexcept
         {
             return pika::execution::experimental::get_env(s.sender);
         }
