@@ -189,10 +189,7 @@ namespace pika::split_tuple_detail {
         {
             PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
 
-            [[noreturn]] void operator()(pika::detail::monostate) const
-            {
-                PIKA_UNREACHABLE;
-            }
+            [[noreturn]] void operator()(pika::detail::monostate) const { PIKA_UNREACHABLE; }
 
             void operator()(pika::execution::detail::stopped_type)
             {
@@ -208,10 +205,7 @@ namespace pika::split_tuple_detail {
                 {
                     pika::execution::experimental::set_stopped(PIKA_MOVE(receiver));
                 }
-                else
-                {
-                    PIKA_UNREACHABLE;
-                }
+                else { PIKA_UNREACHABLE; }
             }
 
             void operator()(error_type const& error)
@@ -283,10 +277,7 @@ namespace pika::split_tuple_detail {
                 auto continuations_local = PIKA_MOVE(continuations);
                 for (auto const& continuation : continuations_local)
                 {
-                    if (continuation)
-                    {
-                        continuation();
-                    }
+                    if (continuation) { continuation(); }
                 }
             }
         }
@@ -353,10 +344,7 @@ namespace pika::split_tuple_detail {
             }
         }
 
-        friend void intrusive_ptr_add_ref(shared_state* p)
-        {
-            ++p->reference_count;
-        }
+        friend void intrusive_ptr_add_ref(shared_state* p) { ++p->reference_count; }
 
         friend void intrusive_ptr_release(shared_state* p)
         {
