@@ -7,7 +7,7 @@
 #include <pika/modules/execution.hpp>
 #include <pika/testing.hpp>
 
-#include "algorithm_test_utils.hpp"
+#include <pika/execution_base/tests/algorithm_test_utils.hpp>
 
 #include <atomic>
 #include <exception>
@@ -84,15 +84,9 @@ struct scheduler_schedule_from
         return {s.schedule_called, s.execute_called, s.tag_invoke_overload_called};
     }
 
-    bool operator==(scheduler_schedule_from const&) const noexcept
-    {
-        return true;
-    }
+    bool operator==(scheduler_schedule_from const&) const noexcept { return true; }
 
-    bool operator!=(scheduler_schedule_from const&) const noexcept
-    {
-        return false;
-    }
+    bool operator!=(scheduler_schedule_from const&) const noexcept { return false; }
 };
 
 template <typename Sender>
@@ -167,15 +161,9 @@ struct scheduler_transfer
         return {s.schedule_called, s.execute_called, s.tag_invoke_overload_called};
     }
 
-    bool operator==(scheduler_transfer const&) const noexcept
-    {
-        return true;
-    }
+    bool operator==(scheduler_transfer const&) const noexcept { return true; }
 
-    bool operator!=(scheduler_transfer const&) const noexcept
-    {
-        return false;
-    }
+    bool operator!=(scheduler_transfer const&) const noexcept { return false; }
 };
 
 template <typename Sender, typename Scheduler>
