@@ -35,6 +35,9 @@
 # pragma GCC diagnostic ignored "-Warray-bounds"
 #endif
 
+// SBO is currently disabled as it seems to be buggy in certain use cases. It can still be
+// explicitly forced to on by defining PIKA_DETAIL_ENABLE_ANY_SENDER_SBO.
+
 namespace pika::detail {
     template <typename T>
     struct empty_vtable_type
@@ -87,8 +90,10 @@ namespace pika::detail {
     {
     protected:
         using base_type = Base;
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
         static constexpr std::size_t embedded_storage_size = EmbeddedStorageSize;
         static constexpr std::size_t alignment_size = AlignmentSize;
+#endif
 
         // The union has two members:
         // - embedded_storage: Embedded storage size array used for types that
@@ -96,11 +101,15 @@ namespace pika::detail {
         //   alignment_size alignment.
         // - heap_storage: A pointer to base_type that is used when objects
         //   don't fit in the embedded storage.
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
         union
         {
             std::aligned_storage_t<embedded_storage_size, alignment_size> embedded_storage;
+#endif
             base_type* heap_storage = nullptr;
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
         };
+#endif
         base_type* object = const_cast<base_type*>(get_empty_vtable<base_type>());
 
         // Returns true when it's safe to use the embedded storage, i.e.
@@ -108,30 +117,34 @@ namespace pika::detail {
         template <typename Impl>
         static constexpr bool can_use_embedded_storage()
         {
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
             constexpr bool fits_storage = sizeof(std::decay_t<Impl>) <= embedded_storage_size;
             constexpr bool sufficiently_aligned = alignof(std::decay_t<Impl>) <= alignment_size;
             return fits_storage && sufficiently_aligned;
+#else
+            return false;
+#endif
         }
 
         bool using_embedded_storage() const noexcept
         {
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
             return object == reinterpret_cast<base_type const*>(&embedded_storage);
+#else
+            return false;
+#endif
         }
 
-        void reset_vtable()
-        {
-            object = const_cast<base_type*>(get_empty_vtable<base_type>());
-        }
+        void reset_vtable() { object = const_cast<base_type*>(get_empty_vtable<base_type>()); }
 
         void release()
         {
             PIKA_ASSERT(!empty());
 
-            if (using_embedded_storage())
-            {
-                get().~base_type();
-            }
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
+            if (using_embedded_storage()) { get().~base_type(); }
             else
+#endif
             {
                 delete heap_storage;
                 heap_storage = nullptr;
@@ -148,6 +161,7 @@ namespace pika::detail {
 
             if (!other.empty())
             {
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
                 if (other.using_embedded_storage())
                 {
                     auto p = reinterpret_cast<base_type*>(&embedded_storage);
@@ -155,6 +169,7 @@ namespace pika::detail {
                     object = p;
                 }
                 else
+#endif
                 {
                     heap_storage = other.heap_storage;
                     other.heap_storage = nullptr;
@@ -170,25 +185,16 @@ namespace pika::detail {
 
         ~movable_sbo_storage()
         {
-            if (!empty())
-            {
-                release();
-            }
+            if (!empty()) { release(); }
         }
 
-        movable_sbo_storage(movable_sbo_storage&& other)
-        {
-            move_assign(PIKA_MOVE(other));
-        }
+        movable_sbo_storage(movable_sbo_storage&& other) { move_assign(PIKA_MOVE(other)); }
 
         movable_sbo_storage& operator=(movable_sbo_storage&& other)
         {
             if (&other != this)
             {
-                if (!empty())
-                {
-                    release();
-                }
+                if (!empty()) { release(); }
 
                 move_assign(PIKA_MOVE(other));
             }
@@ -198,29 +204,18 @@ namespace pika::detail {
         movable_sbo_storage(movable_sbo_storage const&) = delete;
         movable_sbo_storage& operator=(movable_sbo_storage const&) = delete;
 
-        bool empty() const noexcept
-        {
-            return get().empty();
-        }
+        bool empty() const noexcept { return get().empty(); }
 
-        base_type const& get() const noexcept
-        {
-            return *object;
-        }
+        base_type const& get() const noexcept { return *object; }
 
-        base_type& get() noexcept
-        {
-            return *object;
-        }
+        base_type& get() noexcept { return *object; }
 
         template <typename Impl, typename... Ts>
         void store(Ts&&... ts)
         {
-            if (!empty())
-            {
-                release();
-            }
+            if (!empty()) { release(); }
 
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
             if constexpr (can_use_embedded_storage<Impl>())
             {
                 Impl* p = reinterpret_cast<Impl*>(&embedded_storage);
@@ -228,6 +223,7 @@ namespace pika::detail {
                 object = p;
             }
             else
+#endif
             {
                 heap_storage = new Impl(PIKA_FORWARD(Ts, ts)...);
                 object = heap_storage;
@@ -236,10 +232,7 @@ namespace pika::detail {
 
         void reset()
         {
-            if (!empty())
-            {
-                release();
-            }
+            if (!empty()) { release(); }
         }
     };
 
@@ -252,7 +245,9 @@ namespace pika::detail {
 
         using typename storage_base_type::base_type;
 
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
         using storage_base_type::embedded_storage;
+#endif
         using storage_base_type::heap_storage;
         using storage_base_type::object;
         using storage_base_type::release;
@@ -265,6 +260,7 @@ namespace pika::detail {
 
             if (!other.empty())
             {
+#if defined(PIKA_DETAIL_ENABLE_ANY_SENDER_SBO)
                 if (other.using_embedded_storage())
                 {
                     base_type* p = reinterpret_cast<base_type*>(&embedded_storage);
@@ -272,6 +268,7 @@ namespace pika::detail {
                     object = p;
                 }
                 else
+#endif
                 {
                     heap_storage = other.get().clone();
                     object = heap_storage;
@@ -299,10 +296,7 @@ namespace pika::detail {
         {
             if (&other != this)
             {
-                if (!empty())
-                {
-                    release();
-                }
+                if (!empty()) { release(); }
                 copy_assign(other);
             }
             return *this;
@@ -314,10 +308,7 @@ namespace pika::execution::experimental::detail {
     struct any_operation_state_base
     {
         virtual ~any_operation_state_base() = default;
-        virtual bool empty() const noexcept
-        {
-            return false;
-        }
+        virtual bool empty() const noexcept { return false; }
         virtual void start() & noexcept = 0;
     };
 
@@ -349,10 +340,7 @@ namespace pika::execution::experimental::detail {
         {
         }
 
-        void start() & noexcept override
-        {
-            pika::execution::experimental::start(operation_state);
-        }
+        void start() & noexcept override { pika::execution::experimental::start(operation_state); }
     };
 
     class PIKA_EXPORT any_operation_state
@@ -390,10 +378,7 @@ namespace pika::execution::experimental::detail {
         virtual void set_value(Ts... ts) && = 0;
         virtual void set_error(std::exception_ptr ep) && noexcept = 0;
         virtual void set_stopped() && noexcept = 0;
-        virtual bool empty() const noexcept
-        {
-            return false;
-        }
+        virtual bool empty() const noexcept { return false; }
     };
 
     [[noreturn]] PIKA_EXPORT void throw_bad_any_call(
@@ -402,20 +387,11 @@ namespace pika::execution::experimental::detail {
     template <typename... Ts>
     struct empty_any_receiver final : any_receiver_base<Ts...>
     {
-        void move_into(void*) override
-        {
-            PIKA_UNREACHABLE;
-        }
+        void move_into(void*) override { PIKA_UNREACHABLE; }
 
-        bool empty() const noexcept override
-        {
-            return true;
-        }
+        bool empty() const noexcept override { return true; }
 
-        void set_value(Ts...) && override
-        {
-            throw_bad_any_call("any_receiver", "set_value");
-        }
+        void set_value(Ts...) && override { throw_bad_any_call("any_receiver", "set_value"); }
 
         [[noreturn]] void set_error(std::exception_ptr) && noexcept override
         {
@@ -451,10 +427,7 @@ namespace pika::execution::experimental::detail {
         {
         }
 
-        void move_into(void* p) override
-        {
-            new (p) any_receiver_impl(PIKA_MOVE(receiver));
-        }
+        void move_into(void* p) override { new (p) any_receiver_impl(PIKA_MOVE(receiver)); }
 
         void set_value(Ts... ts) && override
         {
@@ -504,15 +477,24 @@ namespace pika::execution::experimental::detail {
         any_receiver& operator=(any_receiver&&) = default;
         any_receiver& operator=(any_receiver const&) = delete;
 
-        friend void tag_invoke(
-            pika::execution::experimental::set_value_t, any_receiver&& r, Ts... ts) noexcept
+        template <typename... Ts_>
+        friend auto tag_invoke(
+            pika::execution::experimental::set_value_t, any_receiver&& r, Ts_&&... ts) noexcept
+            -> decltype(std::declval<base_type>().set_value(PIKA_FORWARD(Ts_, ts)...))
         {
             // We first move the storage to a temporary variable so that
             // this any_receiver is empty after this set_value. Doing
             // PIKA_MOVE(storage.get()).set_value(...) would leave us with a
             // non-empty any_receiver holding a moved-from receiver.
             auto moved_storage = PIKA_MOVE(r.storage);
-            PIKA_MOVE(moved_storage.get()).set_value(PIKA_MOVE(ts)...);
+            try
+            {
+                PIKA_MOVE(moved_storage.get()).set_value(PIKA_FORWARD(Ts_, ts)...);
+            }
+            catch (...)
+            {
+                PIKA_MOVE(moved_storage.get()).set_error(std::current_exception());
+            }
         }
 
         friend void tag_invoke(pika::execution::experimental::set_error_t, any_receiver&& r,
@@ -550,10 +532,7 @@ namespace pika::execution::experimental::detail {
         virtual ~unique_any_sender_base() = default;
         virtual void move_into(void* p) = 0;
         virtual any_operation_state connect(any_receiver<Ts...>&& receiver) && = 0;
-        virtual bool empty() const noexcept
-        {
-            return false;
-        }
+        virtual bool empty() const noexcept { return false; }
     };
 
     template <typename... Ts>
@@ -568,15 +547,9 @@ namespace pika::execution::experimental::detail {
     template <typename... Ts>
     struct empty_unique_any_sender final : unique_any_sender_base<Ts...>
     {
-        void move_into(void*) override
-        {
-            PIKA_UNREACHABLE;
-        }
+        void move_into(void*) override { PIKA_UNREACHABLE; }
 
-        bool empty() const noexcept override
-        {
-            return true;
-        }
+        bool empty() const noexcept override { return true; }
 
         [[noreturn]] any_operation_state connect(any_receiver<Ts...>&&) && override
         {
@@ -587,25 +560,13 @@ namespace pika::execution::experimental::detail {
     template <typename... Ts>
     struct empty_any_sender final : any_sender_base<Ts...>
     {
-        void move_into(void*) override
-        {
-            PIKA_UNREACHABLE;
-        }
+        void move_into(void*) override { PIKA_UNREACHABLE; }
 
-        any_sender_base<Ts...>* clone() const override
-        {
-            PIKA_UNREACHABLE;
-        }
+        any_sender_base<Ts...>* clone() const override { PIKA_UNREACHABLE; }
 
-        void clone_into(void*) const override
-        {
-            PIKA_UNREACHABLE;
-        }
+        void clone_into(void*) const override { PIKA_UNREACHABLE; }
 
-        bool empty() const noexcept override
-        {
-            return true;
-        }
+        bool empty() const noexcept override { return true; }
 
         [[noreturn]] any_operation_state connect(any_receiver<Ts...>&&) const& override
         {
@@ -631,10 +592,7 @@ namespace pika::execution::experimental::detail {
         {
         }
 
-        void move_into(void* p) override
-        {
-            new (p) unique_any_sender_impl(PIKA_MOVE(sender));
-        }
+        void move_into(void* p) override { new (p) unique_any_sender_impl(PIKA_MOVE(sender)); }
 
         any_operation_state connect(any_receiver<Ts...>&& receiver) && override
         {
@@ -654,20 +612,11 @@ namespace pika::execution::experimental::detail {
         {
         }
 
-        void move_into(void* p) override
-        {
-            new (p) any_sender_impl(PIKA_MOVE(sender));
-        }
+        void move_into(void* p) override { new (p) any_sender_impl(PIKA_MOVE(sender)); }
 
-        any_sender_base<Ts...>* clone() const override
-        {
-            return new any_sender_impl(sender);
-        }
+        any_sender_base<Ts...>* clone() const override { return new any_sender_impl(sender); }
 
-        void clone_into(void* p) const override
-        {
-            new (p) any_sender_impl(sender);
-        }
+        void clone_into(void* p) const override { new (p) any_sender_impl(sender); }
 
         any_operation_state connect(any_receiver<Ts...>&& receiver) const& override
         {
@@ -713,6 +662,8 @@ namespace pika::execution::experimental {
       : private detail::any_sender_static_empty_vtable_helper<Ts...>
 #endif
     {
+        static_assert(pika::util::detail::none_of_v<std::is_reference<Ts>...>,
+            "unique_any_sender does not handle references as completion signatures");
         using base_type = detail::unique_any_sender_base<Ts...>;
         template <typename Sender>
         using impl_type = detail::unique_any_sender_impl<Sender, Ts...>;
@@ -789,26 +740,14 @@ namespace pika::execution::experimental {
             {
                 *this = std::forward<Sender>(sender);
             }
-            else
-            {
-                storage.template store<impl_type<Sender>>(PIKA_FORWARD(Sender, sender));
-            }
+            else { storage.template store<impl_type<Sender>>(PIKA_FORWARD(Sender, sender)); }
         }
 
-        void reset()
-        {
-            storage.reset();
-        }
+        void reset() { storage.reset(); }
 
-        bool empty() const noexcept
-        {
-            return storage.empty();
-        }
+        bool empty() const noexcept { return storage.empty(); }
 
-        explicit operator bool() const noexcept
-        {
-            return !empty();
-        }
+        explicit operator bool() const noexcept { return !empty(); }
     };
 
     template <typename... Ts>
@@ -817,6 +756,8 @@ namespace pika::execution::experimental {
       : private detail::any_sender_static_empty_vtable_helper<Ts...>
 #endif
     {
+        static_assert(pika::util::detail::none_of_v<std::is_reference<Ts>...>,
+            "any_sender does not handle references as completion signatures");
         using base_type = detail::any_sender_base<Ts...>;
         template <typename Sender>
         using impl_type = detail::any_sender_impl<Sender, Ts...>;
@@ -907,20 +848,11 @@ namespace pika::execution::experimental {
             }
         }
 
-        void reset()
-        {
-            storage.reset();
-        }
+        void reset() { storage.reset(); }
 
-        bool empty() const noexcept
-        {
-            return storage.empty();
-        }
+        bool empty() const noexcept { return storage.empty(); }
 
-        explicit operator bool() const noexcept
-        {
-            return !empty();
-        }
+        explicit operator bool() const noexcept { return !empty(); }
     };
 
     namespace detail {
