@@ -38,8 +38,8 @@ namespace pika::execution {
 
         /// The type of the associated executor parameters object which is
         /// associated with this execution policy
-        typedef parallel::execution::extract_executor_parameters<executor_type>::type
-            executor_parameters_type;
+        using executor_parameters_type =
+            parallel::execution::extract_executor_parameters<executor_type>::type;
 
         /// The category of the execution agents created by this execution
         /// policy.
@@ -66,10 +66,7 @@ namespace pika::execution {
         ///
         /// \returns The new sequenced_task_policy
         ///
-        constexpr simd_task_policy operator()(task_policy_tag) const
-        {
-            return *this;
-        }
+        constexpr simd_task_policy operator()(task_policy_tag) const { return *this; }
 
         /// Create a new non task policy from itself
         ///
@@ -99,8 +96,8 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor>::value,
                 "pika::traits::is_executor_any<Executor>::value");
 
-            typedef typename parallel::execution::rebind_executor<simd_task_policy, Executor,
-                executor_parameters_type>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<simd_task_policy,
+                Executor, executor_parameters_type>::type;
             return rebound_type(PIKA_FORWARD(Executor, exec), parameters());
         }
 
@@ -126,40 +123,25 @@ namespace pika::execution {
             ParametersType>::type
         with(Parameters&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<simd_task_policy, executor_type,
-                ParametersType>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<simd_task_policy,
+                executor_type, ParametersType>::type;
             return rebound_type(executor(),
                 parallel::execution::join_executor_parameters(PIKA_FORWARD(Parameters, params)...));
         }
 
         using base_policy_type = sequenced_task_policy;
-        base_policy_type base_policy()
-        {
-            return sequenced_task_policy{};
-        }
+        base_policy_type base_policy() { return sequenced_task_policy{}; }
 
     public:
         /// Return the associated executor object.
-        executor_type& executor()
-        {
-            return exec_;
-        }
+        executor_type& executor() { return exec_; }
         /// Return the associated executor object.
-        constexpr executor_type const& executor() const
-        {
-            return exec_;
-        }
+        constexpr executor_type const& executor() const { return exec_; }
 
         /// Return the associated executor parameters object.
-        executor_parameters_type& parameters()
-        {
-            return params_;
-        }
+        executor_parameters_type& parameters() { return params_; }
         /// Return the associated executor parameters object.
-        constexpr executor_parameters_type const& parameters() const
-        {
-            return params_;
-        }
+        constexpr executor_parameters_type const& parameters() const { return params_; }
 
     private:
         executor_type exec_;
@@ -188,8 +170,8 @@ namespace pika::execution {
 
         /// The category of the execution agents created by this execution
         /// policy.
-        typedef typename pika::traits::executor_execution_category<executor_type>::type
-            execution_category;
+        using execution_category =
+            typename pika::traits::executor_execution_category<executor_type>::type;
 
         /// Rebind the type of executor used by this execution policy. The
         /// execution category of Executor shall not be weaker than that of
@@ -208,10 +190,7 @@ namespace pika::execution {
         ///
         /// \returns The new sequenced_task_policy
         ///
-        constexpr simd_task_policy_shim const& operator()(task_policy_tag) const
-        {
-            return *this;
-        }
+        constexpr simd_task_policy_shim const& operator()(task_policy_tag) const { return *this; }
 
         /// Create a new non task policy from itself
         ///
@@ -241,8 +220,9 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor_>::value,
                 "pika::traits::is_executor_any<Executor_>::value");
 
-            typedef typename parallel::execution::rebind_executor<simd_task_policy_shim, Executor_,
-                executor_parameters_type>::type rebound_type;
+            using rebound_type =
+                typename parallel::execution::rebind_executor<simd_task_policy_shim, Executor_,
+                    executor_parameters_type>::type;
             return rebound_type(PIKA_FORWARD(Executor_, exec), params_);
         }
 
@@ -268,8 +248,9 @@ namespace pika::execution {
             ParametersType>::type
         with(Parameters_&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<simd_task_policy_shim,
-                executor_type, ParametersType>::type rebound_type;
+            using rebound_type =
+                typename parallel::execution::rebind_executor<simd_task_policy_shim, executor_type,
+                    ParametersType>::type;
             return rebound_type(exec_,
                 parallel::execution::join_executor_parameters(
                     PIKA_FORWARD(Parameters_, params)...));
@@ -282,26 +263,14 @@ namespace pika::execution {
         }
 
         /// Return the associated executor object.
-        Executor& executor()
-        {
-            return exec_;
-        }
+        Executor& executor() { return exec_; }
         /// Return the associated executor object.
-        constexpr Executor const& executor() const
-        {
-            return exec_;
-        }
+        constexpr Executor const& executor() const { return exec_; }
 
         /// Return the associated executor parameters object.
-        Parameters& parameters()
-        {
-            return params_;
-        }
+        Parameters& parameters() { return params_; }
         /// Return the associated executor parameters object.
-        constexpr Parameters const& parameters() const
-        {
-            return params_;
-        }
+        constexpr Parameters const& parameters() const { return params_; }
 
         /// \cond NOINTERNAL
         constexpr simd_task_policy_shim() = default;
@@ -330,8 +299,8 @@ namespace pika::execution {
 
         /// The type of the associated executor parameters object which is
         /// associated with this execution policy
-        typedef parallel::execution::extract_executor_parameters<executor_type>::type
-            executor_parameters_type;
+        using executor_parameters_type =
+            parallel::execution::extract_executor_parameters<executor_type>::type;
 
         /// The category of the execution agents created by this execution
         /// policy.
@@ -358,19 +327,13 @@ namespace pika::execution {
         ///
         /// \returns The new simd_task_policy
         ///
-        constexpr simd_task_policy operator()(task_policy_tag) const
-        {
-            return simd_task_policy();
-        }
+        constexpr simd_task_policy operator()(task_policy_tag) const { return simd_task_policy(); }
 
         /// Create a new non task policy from itself
         ///
         /// \returns The non task simd policy
         ///
-        constexpr decltype(auto) operator()(non_task_policy_tag /*tag*/) const
-        {
-            return *this;
-        }
+        constexpr decltype(auto) operator()(non_task_policy_tag /*tag*/) const { return *this; }
 
         /// Create a new simd_policy from the given
         /// executor
@@ -394,8 +357,8 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor>::value,
                 "pika::traits::is_executor_any<Executor>::value");
 
-            typedef typename parallel::execution::rebind_executor<simd_policy, Executor,
-                executor_parameters_type>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<simd_policy,
+                Executor, executor_parameters_type>::type;
             return rebound_type(PIKA_FORWARD(Executor, exec), parameters());
         }
 
@@ -421,41 +384,26 @@ namespace pika::execution {
             ParametersType>::type
         with(Parameters&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<simd_policy, executor_type,
-                ParametersType>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<simd_policy,
+                executor_type, ParametersType>::type;
             return rebound_type(executor(),
                 parallel::execution::join_executor_parameters(PIKA_FORWARD(Parameters, params)...));
         }
 
         using base_policy_type = sequenced_policy;
-        base_policy_type base_policy()
-        {
-            return sequenced_policy{};
-        }
+        base_policy_type base_policy() { return sequenced_policy{}; }
 
     public:
         /// Return the associated executor object.
         /// Return the associated executor object.
-        executor_type& executor()
-        {
-            return exec_;
-        }
+        executor_type& executor() { return exec_; }
         /// Return the associated executor object.
-        constexpr executor_type const& executor() const
-        {
-            return exec_;
-        }
+        constexpr executor_type const& executor() const { return exec_; }
 
         /// Return the associated executor parameters object.
-        executor_parameters_type& parameters()
-        {
-            return params_;
-        }
+        executor_parameters_type& parameters() { return params_; }
         /// Return the associated executor parameters object.
-        constexpr executor_parameters_type const& parameters() const
-        {
-            return params_;
-        }
+        constexpr executor_parameters_type const& parameters() const { return params_; }
 
     private:
         executor_type exec_;
@@ -480,8 +428,8 @@ namespace pika::execution {
 
         /// The category of the execution agents created by this execution
         /// policy.
-        typedef typename pika::traits::executor_execution_category<executor_type>::type
-            execution_category;
+        using execution_category =
+            typename pika::traits::executor_execution_category<executor_type>::type;
 
         /// Rebind the type of executor used by this execution policy. The
         /// execution category of Executor shall not be weaker than that of
@@ -509,10 +457,7 @@ namespace pika::execution {
         ///
         /// \returns The non task simd_policy_shim
         ///
-        constexpr decltype(auto) operator()(non_task_policy_tag /*tag*/) const
-        {
-            return *this;
-        }
+        constexpr decltype(auto) operator()(non_task_policy_tag /*tag*/) const { return *this; }
 
         /// Create a new simd_policy from the given
         /// executor
@@ -536,8 +481,8 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor_>::value,
                 "pika::traits::is_executor_any<Executor_>::value");
 
-            typedef typename parallel::execution::rebind_executor<simd_policy_shim, Executor_,
-                executor_parameters_type>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<simd_policy_shim,
+                Executor_, executor_parameters_type>::type;
             return rebound_type(PIKA_FORWARD(Executor_, exec), params_);
         }
 
@@ -563,8 +508,8 @@ namespace pika::execution {
             ParametersType>::type
         with(Parameters_&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<simd_policy_shim, executor_type,
-                ParametersType>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<simd_policy_shim,
+                executor_type, ParametersType>::type;
             return rebound_type(exec_,
                 parallel::execution::join_executor_parameters(
                     PIKA_FORWARD(Parameters_, params)...));
@@ -577,26 +522,14 @@ namespace pika::execution {
         }
 
         /// Return the associated executor object.
-        Executor& executor()
-        {
-            return exec_;
-        }
+        Executor& executor() { return exec_; }
         /// Return the associated executor object.
-        constexpr Executor const& executor() const
-        {
-            return exec_;
-        }
+        constexpr Executor const& executor() const { return exec_; }
 
         /// Return the associated executor parameters object.
-        Parameters& parameters()
-        {
-            return params_;
-        }
+        Parameters& parameters() { return params_; }
         /// Return the associated executor parameters object.
-        constexpr Parameters const& parameters() const
-        {
-            return params_;
-        }
+        constexpr Parameters const& parameters() const { return params_; }
 
         /// \cond NOINTERNAL
         constexpr simd_policy_shim() = default;
@@ -629,8 +562,8 @@ namespace pika::execution {
 
         /// The type of the associated executor parameters object which is
         /// associated with this execution policy
-        typedef parallel::execution::extract_executor_parameters<executor_type>::type
-            executor_parameters_type;
+        using executor_parameters_type =
+            parallel::execution::extract_executor_parameters<executor_type>::type;
 
         /// The category of the execution agents created by this execution
         /// policy.
@@ -657,10 +590,7 @@ namespace pika::execution {
         ///
         /// \returns The new par_simd_task_policy
         ///
-        constexpr par_simd_task_policy operator()(task_policy_tag) const
-        {
-            return *this;
-        }
+        constexpr par_simd_task_policy operator()(task_policy_tag) const { return *this; }
 
         /// Create a new non task policy from itself
         ///
@@ -689,8 +619,8 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor>::value,
                 "pika::traits::is_executor_any<Executor>::value");
 
-            typedef typename parallel::execution::rebind_executor<par_simd_task_policy, Executor,
-                executor_parameters_type>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<par_simd_task_policy,
+                Executor, executor_parameters_type>::type;
             return rebound_type(PIKA_FORWARD(Executor, exec), parameters());
         }
 
@@ -716,40 +646,25 @@ namespace pika::execution {
             ParametersType>::type
         with(Parameters&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<par_simd_task_policy,
-                executor_type, ParametersType>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<par_simd_task_policy,
+                executor_type, ParametersType>::type;
             return rebound_type(executor(),
                 parallel::execution::join_executor_parameters(PIKA_FORWARD(Parameters, params)...));
         }
 
         using base_policy_type = parallel_task_policy;
-        base_policy_type base_policy()
-        {
-            return parallel_task_policy{};
-        }
+        base_policy_type base_policy() { return parallel_task_policy{}; }
 
     public:
         /// Return the associated executor object.
-        executor_type& executor()
-        {
-            return exec_;
-        }
+        executor_type& executor() { return exec_; }
         /// Return the associated executor object.
-        constexpr executor_type const& executor() const
-        {
-            return exec_;
-        }
+        constexpr executor_type const& executor() const { return exec_; }
 
         /// Return the associated executor parameters object.
-        executor_parameters_type& parameters()
-        {
-            return params_;
-        }
+        executor_parameters_type& parameters() { return params_; }
         /// Return the associated executor parameters object.
-        constexpr executor_parameters_type const& parameters() const
-        {
-            return params_;
-        }
+        constexpr executor_parameters_type const& parameters() const { return params_; }
 
     private:
         executor_type exec_;
@@ -767,8 +682,8 @@ namespace pika::execution {
 
         /// The type of the associated executor parameters object which is
         /// associated with this execution policy
-        typedef parallel::execution::extract_executor_parameters<executor_type>::type
-            executor_parameters_type;
+        using executor_parameters_type =
+            parallel::execution::extract_executor_parameters<executor_type>::type;
 
         /// The category of the execution agents created by this execution
         /// policy.
@@ -804,10 +719,7 @@ namespace pika::execution {
         ///
         /// \returns The non task par_simd policy
         ///
-        constexpr decltype(auto) operator()(non_task_policy_tag /*tag*/) const
-        {
-            return *this;
-        }
+        constexpr decltype(auto) operator()(non_task_policy_tag /*tag*/) const { return *this; }
 
         /// Create a new par_simd_policy referencing an executor and
         /// a chunk size.
@@ -826,8 +738,8 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor>::value,
                 "pika::traits::is_executor_any<Executor>::value");
 
-            typedef typename parallel::execution::rebind_executor<par_simd_policy, Executor,
-                executor_parameters_type>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<par_simd_policy,
+                Executor, executor_parameters_type>::type;
             return rebound_type(PIKA_FORWARD(Executor, exec), parameters());
         }
 
@@ -852,40 +764,25 @@ namespace pika::execution {
             ParametersType>::type
         with(Parameters&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<par_simd_policy, executor_type,
-                ParametersType>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<par_simd_policy,
+                executor_type, ParametersType>::type;
             return rebound_type(executor(),
                 parallel::execution::join_executor_parameters(PIKA_FORWARD(Parameters, params)...));
         }
 
         using base_policy_type = parallel_policy;
-        base_policy_type base_policy()
-        {
-            return parallel_policy{};
-        }
+        base_policy_type base_policy() { return parallel_policy{}; }
 
     public:
         /// Return the associated executor object.
-        executor_type& executor()
-        {
-            return exec_;
-        }
+        executor_type& executor() { return exec_; }
         /// Return the associated executor object.
-        constexpr executor_type const& executor() const
-        {
-            return exec_;
-        }
+        constexpr executor_type const& executor() const { return exec_; }
 
         /// Return the associated executor parameters object.
-        executor_parameters_type& parameters()
-        {
-            return params_;
-        }
+        executor_parameters_type& parameters() { return params_; }
         /// Return the associated executor parameters object.
-        constexpr executor_parameters_type const& parameters() const
-        {
-            return params_;
-        }
+        constexpr executor_parameters_type const& parameters() const { return params_; }
 
     private:
         executor_type exec_;
@@ -910,8 +807,8 @@ namespace pika::execution {
 
         /// The category of the execution agents created by this execution
         /// policy.
-        typedef typename pika::traits::executor_execution_category<executor_type>::type
-            execution_category;
+        using execution_category =
+            typename pika::traits::executor_execution_category<executor_type>::type;
 
         /// Rebind the type of executor used by this execution policy. The
         /// execution category of Executor shall not be weaker than that of
@@ -939,10 +836,7 @@ namespace pika::execution {
         ///
         /// \returns The non task par_simd policy
         ///
-        constexpr decltype(auto) operator()(non_task_policy_tag /*tag*/) const
-        {
-            return *this;
-        }
+        constexpr decltype(auto) operator()(non_task_policy_tag /*tag*/) const { return *this; }
 
         /// Create a new par_simd_task_policy_shim from the given
         /// executor
@@ -966,8 +860,8 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor_>::value,
                 "pika::traits::is_executor_any<Executor_>::value");
 
-            typedef typename parallel::execution::rebind_executor<par_simd_policy_shim, Executor_,
-                executor_parameters_type>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<par_simd_policy_shim,
+                Executor_, executor_parameters_type>::type;
             return rebound_type(PIKA_FORWARD(Executor_, exec), params_);
         }
 
@@ -992,8 +886,8 @@ namespace pika::execution {
             ParametersType>::type
         with(Parameters_&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<par_simd_policy_shim,
-                executor_type, ParametersType>::type rebound_type;
+            using rebound_type = typename parallel::execution::rebind_executor<par_simd_policy_shim,
+                executor_type, ParametersType>::type;
             return rebound_type(exec_,
                 parallel::execution::join_executor_parameters(
                     PIKA_FORWARD(Parameters_, params)...));
@@ -1006,26 +900,14 @@ namespace pika::execution {
         }
 
         /// Return the associated executor object.
-        Executor& executor()
-        {
-            return exec_;
-        }
+        Executor& executor() { return exec_; }
         /// Return the associated executor object.
-        constexpr Executor const& executor() const
-        {
-            return exec_;
-        }
+        constexpr Executor const& executor() const { return exec_; }
 
         /// Return the associated executor parameters object.
-        Parameters& parameters()
-        {
-            return params_;
-        }
+        Parameters& parameters() { return params_; }
         /// Return the associated executor parameters object.
-        constexpr Parameters const& parameters() const
-        {
-            return params_;
-        }
+        constexpr Parameters const& parameters() const { return params_; }
 
         /// \cond NOINTERNAL
         constexpr par_simd_policy_shim() = default;
@@ -1060,8 +942,8 @@ namespace pika::execution {
 
         /// The category of the execution agents created by this execution
         /// policy.
-        typedef typename pika::traits::executor_execution_category<executor_type>::type
-            execution_category;
+        using execution_category =
+            typename pika::traits::executor_execution_category<executor_type>::type;
 
         /// Rebind the type of executor used by this execution policy. The
         /// execution category of Executor shall not be weaker than that of
@@ -1080,10 +962,7 @@ namespace pika::execution {
         ///
         /// \returns The new sequenced_task_policy
         ///
-        constexpr par_simd_task_policy_shim operator()(task_policy_tag) const
-        {
-            return *this;
-        }
+        constexpr par_simd_task_policy_shim operator()(task_policy_tag) const { return *this; }
 
         /// Create a new non task policy from itself
         ///
@@ -1113,8 +992,9 @@ namespace pika::execution {
             static_assert(pika::traits::is_executor_any<Executor_>::value,
                 "pika::traits::is_executor_any<Executor_>::value");
 
-            typedef typename parallel::execution::rebind_executor<par_simd_task_policy_shim,
-                Executor_, executor_parameters_type>::type rebound_type;
+            using rebound_type =
+                typename parallel::execution::rebind_executor<par_simd_task_policy_shim, Executor_,
+                    executor_parameters_type>::type;
             return rebound_type(PIKA_FORWARD(Executor_, exec), params_);
         }
 
@@ -1140,8 +1020,9 @@ namespace pika::execution {
             ParametersType>::type
         with(Parameters_&&... params) const
         {
-            typedef typename parallel::execution::rebind_executor<par_simd_task_policy_shim,
-                executor_type, ParametersType>::type rebound_type;
+            using rebound_type =
+                typename parallel::execution::rebind_executor<par_simd_task_policy_shim,
+                    executor_type, ParametersType>::type;
             return rebound_type(exec_,
                 parallel::execution::join_executor_parameters(
                     PIKA_FORWARD(Parameters_, params)...));
@@ -1154,26 +1035,14 @@ namespace pika::execution {
         }
 
         /// Return the associated executor object.
-        Executor& executor()
-        {
-            return exec_;
-        }
+        Executor& executor() { return exec_; }
         /// Return the associated executor object.
-        constexpr Executor const& executor() const
-        {
-            return exec_;
-        }
+        constexpr Executor const& executor() const { return exec_; }
 
         /// Return the associated executor parameters object.
-        Parameters& parameters()
-        {
-            return params_;
-        }
+        Parameters& parameters() { return params_; }
         /// Return the associated executor parameters object.
-        constexpr Parameters const& parameters() const
-        {
-            return params_;
-        }
+        constexpr Parameters const& parameters() const { return params_; }
 
         /// \cond NOINTERNAL
         constexpr par_simd_task_policy_shim() = default;
