@@ -226,10 +226,7 @@ struct callback_receiver
         PIKA_TEST(false);
     }
 
-    friend void tag_invoke(ex::set_stopped_t, callback_receiver&&) noexcept
-    {
-        PIKA_TEST(false);
-    }
+    friend void tag_invoke(ex::set_stopped_t, callback_receiver&&) noexcept { PIKA_TEST(false); }
 
     template <typename... Ts>
     friend void tag_invoke(ex::set_value_t, callback_receiver&& r, Ts&&...) noexcept
@@ -1622,10 +1619,7 @@ void test_bulk()
             PIKA_TEST_NEQ(parent_id, pika::this_thread::get_id());
         }));
 
-        for (int i = 0; i < n; ++i)
-        {
-            PIKA_TEST_EQ(v[i], 1);
-        }
+        for (int i = 0; i < n; ++i) { PIKA_TEST_EQ(v[i], 1); }
     }
 
     for (auto n : ns)
@@ -1639,10 +1633,7 @@ void test_bulk()
                 PIKA_TEST_NEQ(parent_id, pika::this_thread::get_id());
             }));
 
-        for (int i = 0; i < n; ++i)
-        {
-            PIKA_TEST_EQ(v_out[i], i);
-        }
+        for (int i = 0; i < n; ++i) { PIKA_TEST_EQ(v_out[i], i); }
     }
 
     // l-value reference sender
@@ -1657,10 +1648,7 @@ void test_bulk()
         });
         tt::sync_wait(s);
 
-        for (int i = 0; i < n; ++i)
-        {
-            PIKA_TEST_EQ(v[i], 1);
-        }
+        for (int i = 0; i < n; ++i) { PIKA_TEST_EQ(v[i], 1); }
     }
 
     // The specification only allows integral shapes
@@ -1678,10 +1666,7 @@ void test_bulk()
                 string_map.insert(s);
             }));
 
-        for (auto const& s : v_ref)
-        {
-            PIKA_TEST(string_map.find(s) != string_map.end());
-        }
+        for (auto const& s : v_ref) { PIKA_TEST(string_map.find(s) != string_map.end()); }
     }
 #endif
 
@@ -1695,38 +1680,23 @@ void test_bulk()
         try
         {
             tt::sync_wait(ex::transfer_just(ex::thread_pool_scheduler{}) | ex::bulk(n, [&v](int i) {
-                if (i == i_fail)
-                {
-                    throw std::runtime_error("error");
-                }
+                if (i == i_fail) { throw std::runtime_error("error"); }
                 v[i] = i;
             }));
 
-            if (expect_exception)
-            {
-                PIKA_TEST(false);
-            }
+            if (expect_exception) { PIKA_TEST(false); }
         }
         catch (std::runtime_error const& e)
         {
-            if (!expect_exception)
-            {
-                PIKA_TEST(false);
-            }
+            if (!expect_exception) { PIKA_TEST(false); }
 
             PIKA_TEST_EQ(std::string(e.what()), std::string("error"));
         }
 
-        if (expect_exception)
-        {
-            PIKA_TEST_EQ(v[i_fail], -1);
-        }
+        if (expect_exception) { PIKA_TEST_EQ(v[i_fail], -1); }
         else
         {
-            for (int i = 0; i < n; ++i)
-            {
-                PIKA_TEST_EQ(v[i], i);
-            }
+            for (int i = 0; i < n; ++i) { PIKA_TEST_EQ(v[i], i); }
         }
     }
 }
@@ -1877,7 +1847,7 @@ void test_split_tuple()
 
             try
             {
-                tt::sync_wait(std::move(s));
+                tt::sync_wait(std::forward<decltype(s)>(s));
                 PIKA_TEST(false);
             }
             catch (std::runtime_error const& e)
