@@ -12,12 +12,12 @@
 namespace pika {
 
     /// \namespace lcos
-    namespace lcos { namespace detail {
+    namespace lcos::detail {
         template <typename Result>
         struct future_data;
 
         struct future_data_refcnt_base;
-    }}    // namespace lcos::detail
+    }    // namespace lcos::detail
 
     template <typename R>
     class future;
