@@ -13,8 +13,8 @@ int pika_main()
 {
     pika::shared_future<int> f1 = pika::make_ready_future(42);
 
-    pika::future<int> f2 = f1.then(
-        [](pika::shared_future<int>&&) { return pika::make_ready_future(43); });
+    pika::future<int> f2 =
+        f1.then([](pika::shared_future<int>&&) { return pika::make_ready_future(43); });
 
     PIKA_TEST_EQ(f1.get(), 42);
     PIKA_TEST_EQ(f2.get(), 43);
@@ -25,8 +25,7 @@ int pika_main()
 int main(int argc, char* argv[])
 {
     // Initialize and run pika
-    PIKA_TEST_EQ_MSG(pika::init(pika_main, argc, argv), 0,
-        "pika main exited with non-zero status");
+    PIKA_TEST_EQ_MSG(pika::init(pika_main, argc, argv), 0, "pika main exited with non-zero status");
 
     return 0;
 }
