@@ -167,6 +167,12 @@ namespace pika {
         return 0 == detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, false);
     }
 
+    bool start(int argc, const char* const* argv, init_params const& params)
+    {
+        util::detail::function<int(pika::program_options::variables_map&)> main_f;
+        return 0 == detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, false);
+    }
+
     int finalize(error_code& ec)
     {
         if (!is_running())
@@ -176,8 +182,7 @@ namespace pika {
             return -1;
         }
 
-        if (&ec != &throws)
-            ec = make_success_code();
+        if (&ec != &throws) ec = make_success_code();
 
         runtime* rt = get_runtime_ptr();
         if (nullptr == rt)
@@ -187,7 +192,7 @@ namespace pika {
             return -1;
         }
 
-        rt->finalize(0);
+        rt->finalize();
 
         return 0;
     }
@@ -197,7 +202,7 @@ namespace pika {
         if (threads::detail::get_self_ptr())
         {
             PIKA_THROWS_IF(ec, pika::error::invalid_status, "pika::stop",
-                "this function cannot be called from an pika thread");
+                "this function cannot be called from a pika thread");
             return -1;
         }
 
@@ -237,7 +242,7 @@ namespace pika {
         if (threads::detail::get_self_ptr())
         {
             PIKA_THROWS_IF(ec, pika::error::invalid_status, "pika::suspend",
-                "this function cannot be called from an pika thread");
+                "this function cannot be called from a pika thread");
             return -1;
         }
 
@@ -257,7 +262,7 @@ namespace pika {
         if (threads::detail::get_self_ptr())
         {
             PIKA_THROWS_IF(ec, pika::error::invalid_status, "pika::resume",
-                "this function cannot be called from an pika thread");
+                "this function cannot be called from a pika thread");
             return -1;
         }
 
@@ -285,10 +290,7 @@ namespace pika {
                 util::enable_lock_detection();
                 util::trace_depth_lock_detection(cmdline.rtcfg_.trace_depth());
             }
-            else
-            {
-                util::disable_lock_detection();
-            }
+            else { util::disable_lock_detection(); }
 #endif
 #ifdef PIKA_HAVE_THREAD_DEADLOCK_DETECTION
             threads::detail::set_deadlock_detection_enabled(
@@ -319,11 +321,9 @@ namespace pika {
                 rt.get_config().load_application_configuration(config.c_str());
             }
 
-            if (!!startup)
-                rt.add_startup_function(PIKA_MOVE(startup));
+            if (!!startup) rt.add_startup_function(PIKA_MOVE(startup));
 
-            if (!!shutdown)
-                rt.add_shutdown_function(PIKA_MOVE(shutdown));
+            if (!!shutdown) rt.add_shutdown_function(PIKA_MOVE(shutdown));
 
             if (vm.count("pika:dump-config-initial"))
             {
@@ -333,8 +333,7 @@ namespace pika {
                 std::cout << "-----------------------------------------\n";
             }
 
-            if (vm.count("pika:dump-config"))
-                rt.add_startup_function(dump_config(rt));
+            if (vm.count("pika:dump-config")) rt.add_startup_function(dump_config(rt));
         }
 
         ///////////////////////////////////////////////////////////////////////
@@ -348,10 +347,9 @@ namespace pika {
             add_startup_functions(rt, vm, PIKA_MOVE(startup), PIKA_MOVE(shutdown));
 
             // Run this runtime instance using the given function f.
-            if (!f.empty())
-                return rt.run(util::detail::bind_front(f, vm));
+            if (!f.empty()) return rt.run(util::detail::bind_front(f, vm));
 
-            // Run this runtime instance without an pika_main
+            // Run this runtime instance without a pika_main
             return rt.run();
         }
 
@@ -370,7 +368,7 @@ namespace pika {
                 return rt.start(util::detail::bind_front(f, vm));
             }
 
-            // Run this runtime instance without an pika_main
+            // Run this runtime instance without a pika_main
             return rt.start();
         }
 
@@ -465,14 +463,10 @@ namespace pika {
             int result = 0;
             try
             {
-                if ((result = ensure_no_runtime_is_up()) != 0)
-                {
-                    return result;
-                }
+                if ((result = ensure_no_runtime_is_up()) != 0) { return result; }
 
                 pika::detail::command_line_handling cmdline{
-                    pika::util::runtime_configuration(argv[0], pika::runtime_mode::local),
-                    params.cfg, f};
+                    pika::util::runtime_configuration(argv[0]), params.cfg, f};
 
                 // scope exception handling to resource partitioner initialization
                 // any exception thrown during run_or_start below are handled
@@ -505,16 +499,12 @@ namespace pika {
                     // contain --pika:help or --pika:version, on error result is < 0)
                     if (result != 0)
                     {
-                        if (result > 0)
-                            result = 0;
+                        if (result > 0) result = 0;
                         return result;
                     }
 
                     // If thread_pools initialization in user main
-                    if (params.rp_callback)
-                    {
-                        params.rp_callback(rp, cmdline.vm_);
-                    }
+                    if (params.rp_callback) { params.rp_callback(rp, cmdline.vm_); }
 
                     // Setup all internal parameters of the resource_partitioner
                     rp.configure_pools();
