@@ -14,20 +14,17 @@
 
 void is_sentinel_for()
 {
-    PIKA_TEST_MSG((pika::traits::is_sentinel_for<sentinel<int64_t>,
-                      iterator<std::int64_t>>::value),
+    PIKA_TEST_MSG((pika::traits::is_sentinel_for<sentinel<int64_t>, iterator<std::int64_t>>::value),
         "Sentinel value is not proper for given iterator");
 
-    PIKA_TEST_MSG(
-        (!pika::traits::is_sentinel_for<std::int64_t, std::int64_t>::value),
+    PIKA_TEST_MSG((!pika::traits::is_sentinel_for<std::int64_t, std::int64_t>::value),
         "Integer - integer pair is incompatible pair");
 
     PIKA_TEST_MSG((pika::traits::is_sentinel_for<std::vector<int>::iterator,
                       std::vector<int>::iterator>::value),
         "Incompatible begin - end iterator pair on vector");
 
-    PIKA_TEST_MSG((!pika::traits::is_sentinel_for<std::string,
-                      std::string::iterator>::value),
+    PIKA_TEST_MSG((!pika::traits::is_sentinel_for<std::string, std::string::iterator>::value),
         "String - string::iterator is incompatible pair");
 }
 
