@@ -22,22 +22,14 @@ namespace pika::util::logging {
     {
         switch (value)
         {
-        case pika::util::logging::level::enable_all:
-            return "<all>";
-        case pika::util::logging::level::debug:
-            return "<debug>";
-        case pika::util::logging::level::info:
-            return "<info>";
-        case pika::util::logging::level::warning:
-            return "<warning>";
-        case pika::util::logging::level::error:
-            return "<error>";
-        case pika::util::logging::level::fatal:
-            return "<fatal>";
-        case pika::util::logging::level::always:
-            return "<always>";
-        default:
-            break;
+        case pika::util::logging::level::enable_all: return "<all>";
+        case pika::util::logging::level::debug: return "<debug>";
+        case pika::util::logging::level::info: return "<info>";
+        case pika::util::logging::level::warning: return "<warning>";
+        case pika::util::logging::level::error: return "<error>";
+        case pika::util::logging::level::fatal: return "<fatal>";
+        case pika::util::logging::level::always: return "<always>";
+        default: break;
         }
 
         return '<' + std::to_string(static_cast<int>(value)) + '>';
