@@ -124,14 +124,8 @@ int pika_main()
             {
                 pika::threads::detail::resume_processing_unit(tp, thread_num).get();
 
-                if (thread_num > 0)
-                {
-                    --thread_num;
-                }
-                else
-                {
-                    up = true;
-                }
+                if (thread_num > 0) { --thread_num; }
+                else { up = true; }
             }
         }
 
@@ -198,10 +192,7 @@ int main(int argc, char* argv[])
         pika::resource::scheduling_policy::shared_priority,
     };
 
-    for (auto const scheduler : schedulers)
-    {
-        test_scheduler(argc, argv, scheduler);
-    }
+    for (auto const scheduler : schedulers) { test_scheduler(argc, argv, scheduler); }
 
     return 0;
 }
