@@ -21,7 +21,6 @@
 #include <pika/runtime/thread_hooks.hpp>
 #include <pika/runtime/thread_mapper.hpp>
 #include <pika/runtime_configuration/runtime_configuration.hpp>
-#include <pika/runtime_configuration/runtime_mode.hpp>
 #include <pika/threading_base/callback_notifier.hpp>
 
 #include <atomic>
@@ -117,7 +116,7 @@ namespace pika {
         ///        main \a thread and block waiting for all threads to
         ///        finish
         ///
-        /// \param func       [in] This is the main function of an pika
+        /// \param func       [in] This is the main function of a pika
         ///                   application. It will be scheduled for execution
         ///                   by the thread manager as soon as the runtime has
         ///                   been initialized. This function is expected to
@@ -149,7 +148,7 @@ namespace pika {
 
         /// \brief Start the runtime system
         ///
-        /// \param func       [in] This is the main function of an pika
+        /// \param func       [in] This is the main function of a pika
         ///                   application. It will be scheduled for execution
         ///                   by the thread manager as soon as the runtime has
         ///                   been initialized. This function is expected to
@@ -206,7 +205,7 @@ namespace pika {
         ///    \brief Resume the runtime system
         virtual int resume();
 
-        virtual int finalize(double /*shutdown_timeout*/);
+        virtual int finalize();
 
         ///  \brief Return true if networking is enabled.
         virtual bool is_networking_enabled();
@@ -364,10 +363,7 @@ namespace pika {
             return std::uint32_t(-1);
         }
 
-        virtual std::uint32_t assign_cores()
-        {
-            return std::uint32_t(-1);
-        }
+        virtual std::uint32_t assign_cores() { return std::uint32_t(-1); }
 
     protected:
         void init_global_data();
