@@ -16,6 +16,7 @@
 #include <pika/schedulers/deadlock_detection.hpp>
 #include <pika/schedulers/lockfree_queue_backends.hpp>
 #include <pika/schedulers/thread_queue.hpp>
+#include <pika/threading_base/detail/global_activity_count.hpp>
 #include <pika/threading_base/scheduler_base.hpp>
 #include <pika/threading_base/thread_data.hpp>
 #include <pika/threading_base/thread_num_tss.hpp>
@@ -98,9 +99,9 @@ namespace pika::threads::detail {
           , steals_in_numa_domain_()
           , steals_outside_numa_domain_()
           , numa_domain_masks_(init.num_queues_,
-                ::pika::threads::detail::create_topology().get_machine_affinity_mask())
+                ::pika::threads::detail::get_topology().get_machine_affinity_mask())
           , outside_numa_domain_masks_(init.num_queues_,
-                ::pika::threads::detail::create_topology().get_machine_affinity_mask())
+                ::pika::threads::detail::get_topology().get_machine_affinity_mask())
         {
             ::pika::threads::detail::resize(
                 steals_in_numa_domain_, threads::detail::hardware_concurrency());
@@ -117,14 +118,10 @@ namespace pika::threads::detail {
 
         virtual ~local_queue_scheduler()
         {
-            for (std::size_t i = 0; i != queues_.size(); ++i)
-                delete queues_[i];
+            for (std::size_t i = 0; i != queues_.size(); ++i) delete queues_[i];
         }
 
-        static std::string get_scheduler_name()
-        {
-            return "local_queue_scheduler";
-        }
+        static std::string get_scheduler_name() { return "local_queue_scheduler"; }
 
 #ifdef PIKA_HAVE_THREAD_CREATION_AND_CLEANUP_RATES
         std::uint64_t get_creation_time(bool reset) override
@@ -264,6 +261,8 @@ namespace pika::threads::detail {
         void create_thread(threads::detail::thread_init_data& data,
             threads::detail::thread_id_ref_type* id, error_code& ec) override
         {
+            pika::threads::detail::increment_global_activity_count();
+
             std::size_t num_thread =
                 data.schedulehint.mode == execution::thread_schedule_hint_mode::thread ?
                 data.schedulehint.hint :
@@ -271,14 +270,8 @@ namespace pika::threads::detail {
 
             std::size_t queue_size = queues_.size();
 
-            if (std::size_t(-1) == num_thread)
-            {
-                num_thread = curr_queue_++ % queue_size;
-            }
-            else if (num_thread >= queue_size)
-            {
-                num_thread %= queue_size;
-            }
+            if (std::size_t(-1) == num_thread) { num_thread = curr_queue_++ % queue_size; }
+            else if (num_thread >= queue_size) { num_thread %= queue_size; }
 
             std::unique_lock<pu_mutex_type> l;
             num_thread = select_active_pu(l, num_thread);
@@ -312,21 +305,16 @@ namespace pika::threads::detail {
                 bool result = q->get_next_thread(thrd);
 
                 q->increment_num_pending_accesses();
-                if (result)
-                    return true;
+                if (result) return true;
                 q->increment_num_pending_misses();
 
                 bool have_staged = q->get_staged_queue_length(std::memory_order_relaxed) != 0;
 
                 // Give up, we should have work to convert.
-                if (have_staged)
-                    return false;
+                if (have_staged) return false;
             }
 
-            if (!running)
-            {
-                return false;
-            }
+            if (!running) { return false; }
 
             bool numa_stealing = has_scheduler_mode(scheduler_mode::enable_stealing_numa);
             if (!numa_stealing)
@@ -428,21 +416,12 @@ namespace pika::threads::detail {
             {
                 num_thread = schedulehint.hint;
             }
-            else
-            {
-                allow_fallback = false;
-            }
+            else { allow_fallback = false; }
 
             std::size_t queue_size = queues_.size();
 
-            if (std::size_t(-1) == num_thread)
-            {
-                num_thread = curr_queue_++ % queue_size;
-            }
-            else if (num_thread >= queue_size)
-            {
-                num_thread %= queue_size;
-            }
+            if (std::size_t(-1) == num_thread) { num_thread = curr_queue_++ % queue_size; }
+            else if (num_thread >= queue_size) { num_thread %= queue_size; }
 
             std::unique_lock<pu_mutex_type> l;
             num_thread = select_active_pu(l, num_thread, allow_fallback);
@@ -470,21 +449,12 @@ namespace pika::threads::detail {
             {
                 num_thread = schedulehint.hint;
             }
-            else
-            {
-                allow_fallback = false;
-            }
+            else { allow_fallback = false; }
 
             std::size_t queue_size = queues_.size();
 
-            if (std::size_t(-1) == num_thread)
-            {
-                num_thread = curr_queue_++ % queue_size;
-            }
-            else if (num_thread >= queue_size)
-            {
-                num_thread %= queue_size;
-            }
+            if (std::size_t(-1) == num_thread) { num_thread = curr_queue_++ % queue_size; }
+            else if (num_thread >= queue_size) { num_thread %= queue_size; }
 
             std::unique_lock<pu_mutex_type> l;
             num_thread = select_active_pu(l, num_thread, allow_fallback);
@@ -500,6 +470,8 @@ namespace pika::threads::detail {
         {
             PIKA_ASSERT(thrd->get_scheduler_base() == this);
             thrd->get_queue<thread_queue_type>().destroy_thread(thrd);
+
+            pika::threads::detail::decrement_global_activity_count();
         }
 
         ///////////////////////////////////////////////////////////////////////
@@ -671,14 +643,10 @@ namespace pika::threads::detail {
             bool result = true;
 
             result = queues_[num_thread]->wait_or_add_new(running, added) && result;
-            if (0 != added)
-                return result;
+            if (0 != added) return result;
 
             // Check if we have been disabled
-            if (!running)
-            {
-                return true;
-            }
+            if (!running) { return true; }
 
             bool numa_stealing_ = has_scheduler_mode(scheduler_mode::enable_stealing_numa);
             // limited or no stealing across domains
@@ -818,7 +786,7 @@ namespace pika::threads::detail {
 
             queues_[num_thread]->on_start_thread(num_thread);
 
-            auto const& topo = ::pika::threads::detail::create_topology();
+            auto const& topo = ::pika::threads::detail::get_topology();
 
             // pre-calculate certain constants for the given thread number
             std::size_t num_pu = affinity_data_.get_pu_num(num_thread);
