@@ -28,18 +28,17 @@ namespace pika::util::detail {
     }
 
     template <typename Lock>
-    std::enable_if_t<has_owns_lock<Lock>::value> assert_owns_lock(Lock const& l, long) noexcept
+    std::enable_if_t<has_owns_lock<Lock>::value>
+    assert_owns_lock([[maybe_unused]] Lock const& l, long) noexcept
     {
         PIKA_ASSERT(l.owns_lock());
-        PIKA_UNUSED(l);
     }
 
     template <typename Lock>
     std::enable_if_t<has_owns_lock<Lock>::value>
-    assert_doesnt_own_lock(Lock const& l, long) noexcept
+    assert_doesnt_own_lock([[maybe_unused]] Lock const& l, long) noexcept
     {
         PIKA_ASSERT(!l.owns_lock());
-        PIKA_UNUSED(l);
     }
 }    // namespace pika::util::detail
 
