@@ -23,8 +23,7 @@ namespace pika::threads::detail {
         case thread_schedule_state::pending:
         case thread_schedule_state::pending_do_not_schedule:
         case thread_schedule_state::pending_boost:
-        case thread_schedule_state::suspended:
-            break;
+        case thread_schedule_state::suspended: break;
 
         default:
         {
@@ -64,12 +63,10 @@ namespace pika::threads::detail {
                 data.parent_phase = self->get_thread_phase();
             }
         }
-        if (0 == data.parent_locality_id)
-            data.parent_locality_id = get_locality_id(pika::throws);
+        if (0 == data.parent_locality_id) data.parent_locality_id = get_locality_id(pika::throws);
 #endif
 
-        if (nullptr == data.scheduler_base)
-            data.scheduler_base = scheduler;
+        if (nullptr == data.scheduler_base) data.scheduler_base = scheduler;
 
         // Pass critical priority from parent to child.
         if (self)
