@@ -29,19 +29,13 @@ namespace pika_start {
 namespace pika::threads::detail {
     static get_default_pool_type get_default_pool;
 
-    void set_get_default_pool(get_default_pool_type f)
-    {
-        get_default_pool = f;
-    }
+    void set_get_default_pool(get_default_pool_type f) { get_default_pool = f; }
 
     thread_pool_base* get_self_or_default_pool()
     {
         thread_pool_base* pool = nullptr;
         auto thrd_data = get_self_id_data();
-        if (thrd_data)
-        {
-            pool = thrd_data->get_scheduler_base()->get_parent_pool();
-        }
+        if (thrd_data) { pool = thrd_data->get_scheduler_base()->get_parent_pool(); }
         else if (get_default_pool)
         {
             pool = get_default_pool();
@@ -52,7 +46,7 @@ namespace pika::threads::detail {
             PIKA_THROW_EXCEPTION(pika::error::invalid_status,
                 "pika::threads::detail::get_self_or_default_pool",
                 "Attempting to register a thread outside the pika runtime and no default pool "
-                "handler is installed. Did you mean to run this on an pika thread?");
+                "handler is installed. Did you mean to run this on a pika thread?");
         }
 
         return pool;
