@@ -77,8 +77,7 @@ void print_results(std::uint64_t cores, double walltime)
 ///////////////////////////////////////////////////////////////////////////////
 std::uint64_t shuffler(std::mt19937_64& prng, std::uint64_t high)
 {
-    if (high == 0)
-        throw std::logic_error("high value was 0");
+    if (high == 0) throw std::logic_error("high value was 0");
 
     // Our range is [0, x).
     std::uniform_int_distribution<std::uint64_t> dist(0, high - 1);
@@ -89,19 +88,16 @@ std::uint64_t shuffler(std::mt19937_64& prng, std::uint64_t high)
 ///////////////////////////////////////////////////////////////////////////////
 int pika_main(variables_map& vm)
 {
-    if (vm.count("no-header"))
-        header = false;
+    if (vm.count("no-header")) header = false;
 
     ///////////////////////////////////////////////////////////////////////////
     // Initialize the PRNG seed.
-    if (!seed)
-        seed = std::uint64_t(std::time(nullptr));
+    if (!seed) seed = std::uint64_t(std::time(nullptr));
 
     {
         ///////////////////////////////////////////////////////////////////////
         // Validate command-line arguments.
-        if (0 == tasks)
-            throw std::invalid_argument("count of 0 tasks specified\n");
+        if (0 == tasks) throw std::invalid_argument("count of 0 tasks specified\n");
 
         if (min_delay > max_delay)
             throw std::invalid_argument("minimum delay cannot be larger than maximum delay\n");
@@ -153,11 +149,9 @@ int pika_main(variables_map& vm)
 
             std::uint64_t const payload = dist(prng);
 
-            if (payload < min_delay)
-                throw std::logic_error("task delay is below minimum");
+            if (payload < min_delay) throw std::logic_error("task delay is below minimum");
 
-            if (payload > max_delay)
-                throw std::logic_error("task delay is above maximum");
+            if (payload > max_delay) throw std::logic_error("task delay is above maximum");
 
             current_sum += payload;
             payloads.push_back(payload);
@@ -169,12 +163,10 @@ int pika_main(variables_map& vm)
 
         ///////////////////////////////////////////////////////////////////////
         // Validate the payloads.
-        if (payloads.size() != tasks)
-            throw std::logic_error("incorrect number of tasks generated");
+        if (payloads.size() != tasks) throw std::logic_error("incorrect number of tasks generated");
 
         std::uint64_t const payloads_sum = std::accumulate(payloads.begin(), payloads.end(), 0ULL);
-        if (payloads_sum != total_delay)
-            throw std::logic_error("incorrect total delay generated");
+        if (payloads_sum != total_delay) throw std::logic_error("incorrect total delay generated");
 
         ///////////////////////////////////////////////////////////////////////
         // Start the clock.
@@ -192,8 +184,7 @@ int pika_main(variables_map& vm)
 
         ///////////////////////////////////////////////////////////////////////
         // Wait for the work to finish.
-        do
-        {
+        do {
             // Reschedule pika_main until all other pika-threads have finished. We
             // should be resumed after most of the null pika-threads have been
             // executed. If we haven't, we just reschedule ourselves again.
